from nqrduck.module.module_controller import ModuleController

# If the module is called "duck" the class would be called "DuckController"

class ModuleController(ModuleController):

    def __init__(self, module):
        """Initialize the controller."""
        super().__init__(module)

    def on_loading(self):
        """This method is called when the module is loaded."""
        pass


from nqrduck.module.module_view import ModuleView

# This is the widget that is loaded into the module view.
# It is generated from the .ui file in the same directory using the pyuic6 command.
from .widget import Ui_Form

from  PyQt6.QtWidgets import QWidget

# If the module is called "duck" the class would be called "DuckView"

class ModuleView(ModuleView):

    def __init__(self, module):
        super().__init__(module)

        widget = QWidget()
        self._ui_form = Ui_Form()
        self._ui_form.setupUi(self)
        self.widget = widget


# Form implementation generated from reading ui file '../Modules/nqrduck-module/src/nqrduck_module/resources/module_widget.ui'
#
# Created by: PyQt6 UI code generator 6.5.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(1920, 1080)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButton = QtWidgets.QPushButton(parent=Form)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.pushButton.setText(_translate("Form", "Test"))



from nqrduck.module.module_model import ModuleModel

# If the module is called "duck" the class would be called "DuckModel"

class ModuleModel(ModuleModel):

    def __init__(self, module):
        """Initialize the model."""
        super().__init__(module)


from nqrduck.module.module import Module
# If the module is called "duck" the following line would be:
# from .model import DuckModel
from .model import ModuleModel
# If the module is called "duck" the following line would be:
# from .view import DuckView
from .view import ModuleView
# If the module is called "duck" the following line would be:
# from .controller import DuckController
from .controller import ModuleController

# If the module is called "duck" the following line would be:
# Duck = Module(DuckModel, DuckView, DuckController)
module = Module(ModuleModel, ModuleView, ModuleController)